📚 API Reference
=================

.. automodule:: chameleon_log
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: chameleon_log.rich
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: chameleon_log.journald
   :members:
   :undoc-members:
   :show-inheritance:
